@@ -243,6 +243,7 @@ class Purchase(
     @classmethod
     def __setup__(cls):
         super(Purchase, cls).__setup__()
+        cls.create_date.select = True
         cls._order = [
             ('purchase_date', 'DESC NULLS FIRST'),
             ('id', 'DESC'),
@@ -363,9 +364,6 @@ class Purchase(
                     values=['processing'],
                     where=sql_table.id.in_(sub_query.select(sub_query.id))))
 
-        # Add index on create_date
-        table.index_action('create_date', action='add')
-
         # Migration from 5.6: rename state cancel to cancelled
         cursor.execute(*sql_table.update(
                 [sql_table.state], ['cancelled'],
@@ -1447,10 +1445,10 @@ class Line(sequence_ordered(), ModelSQL, ModelView):
 
     @fields.depends('moves', methods=['planned_delivery_date'])
     def on_change_with_delivery_date(self, name=None):
-        if self.moves:
+        moves = [m for m in self.moves if m.state != 'cancelled']
+        if moves:
             dates = filter(
-                None, (m.effective_date or m.planned_date for m in self.moves
-                    if m.state != 'cancelled'))
+                None, (m.effective_date or m.planned_date for m in moves))
             return min(dates, default=None)
         return self.planned_delivery_date
 
